==> ViennaCL-1.6.2.tar.gz: ViennaCL-1.6.2/doc/html/examples.js <==
var examples =
[
    [ "amg.cpp", "amg_8cpp-example.html", null ],
    [ "bandwidth-reduction.cpp", "bandwidth-reduction_8cpp-example.html", null ],
    [ "bisect.cpp", "bisect_8cpp-example.html", null ],
    [ "blas1.cpp", "blas1_8cpp-example.html", null ],
    [ "blas2.cpp", "blas2_8cpp-example.html", null ],
    [ "blas3.cpp", "blas3_8cpp-example.html", null ],
    [ "custom-context.cpp", "custom-context_8cpp-example.html", null ],
    [ "custom-kernels.cpp", "custom-kernels_8cpp-example.html", null ],
    [ "eigen-with-viennacl.cpp", "eigen-with-viennacl_8cpp-example.html", null ],
    [ "examples/tutorial/libviennacl.cpp", "examples_2tutorial_2libviennacl_8cpp-example.html", null ],
    [ "fft.cpp", "fft_8cpp-example.html", null ],
    [ "iterative-eigen.cpp", "iterative-eigen_8cpp-example.html", null ],
    [ "iterative-mtl4.cpp", "iterative-mtl4_8cpp-example.html", null ],
    [ "iterative-ublas.cpp", "iterative-ublas_8cpp-example.html", null ],
    [ "iterative.cpp", "iterative_8cpp-example.html", null ],
    [ "lanczos.cpp", "lanczos_8cpp-example.html", null ],
    [ "least-squares.cpp", "least-squares_8cpp-example.html", null ],
    [ "matrix-range.cpp", "matrix-range_8cpp-example.html", null ],
    [ "mtl4-with-viennacl.cpp", "mtl4-with-viennacl_8cpp-example.html", null ],
    [ "multithreaded.cpp", "multithreaded_8cpp-example.html", null ],
    [ "multithreaded_cg.cpp", "multithreaded_cg_8cpp-example.html", null ],
    [ "nmf.cpp", "nmf_8cpp-example.html", null ],
    [ "power-iter.cpp", "power-iter_8cpp-example.html", null ],
    [ "qr.cpp", "qr_8cpp-example.html", null ],
    [ "qr_method.cpp", "qr_method_8cpp-example.html", null ],
    [ "scheduler.cpp", "scheduler_8cpp-example.html", null ],
    [ "spai.cpp", "spai_8cpp-example.html", null ],
    [ "sparse.cpp", "sparse_8cpp-example.html", null ],
    [ "structured-matrices.cpp", "structured-matrices_8cpp-example.html", null ],
    [ "tql2.cpp", "tql2_8cpp-example.html", null ],
    [ "vector-range.cpp", "vector-range_8cpp-example.html", null ],
    [ "viennacl-info.cpp", "viennacl-info_8cpp-example.html", null ],
    [ "wrap-host-buffer.cpp", "wrap-host-buffer_8cpp-example.html", null ]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/examples.js <==
var examples =
[
    [ "amg.cpp", "amg_8cpp-example.html", null ],
    [ "armadillo-with-viennacl.cpp", "armadillo-with-viennacl_8cpp-example.html", null ],
    [ "bandwidth-reduction.cpp", "bandwidth-reduction_8cpp-example.html", null ],
    [ "bisect.cpp", "bisect_8cpp-example.html", null ],
    [ "blas1.cpp", "blas1_8cpp-example.html", null ],
    [ "blas2.cpp", "blas2_8cpp-example.html", null ],
    [ "blas3.cpp", "blas3_8cpp-example.html", null ],
    [ "custom-context.cpp", "custom-context_8cpp-example.html", null ],
    [ "custom-kernels.cpp", "custom-kernels_8cpp-example.html", null ],
    [ "eigen-with-viennacl.cpp", "eigen-with-viennacl_8cpp-example.html", null ],
    [ "examples/tutorial/libviennacl.cpp", "examples_2tutorial_2libviennacl_8cpp-example.html", null ],
    [ "fft.cpp", "fft_8cpp-example.html", null ],
    [ "iterative-armadillo.cpp", "iterative-armadillo_8cpp-example.html", null ],
    [ "iterative-custom.cpp", "iterative-custom_8cpp-example.html", null ],
    [ "iterative-eigen.cpp", "iterative-eigen_8cpp-example.html", null ],
    [ "iterative-mtl4.cpp", "iterative-mtl4_8cpp-example.html", null ],
    [ "iterative-ublas.cpp", "iterative-ublas_8cpp-example.html", null ],
    [ "iterative.cpp", "iterative_8cpp-example.html", null ],
    [ "lanczos.cpp", "lanczos_8cpp-example.html", null ],
    [ "least-squares.cpp", "least-squares_8cpp-example.html", null ],
    [ "matrix-free.cpp", "matrix-free_8cpp-example.html", null ],
    [ "matrix-range.cpp", "matrix-range_8cpp-example.html", null ],
    [ "mtl4-with-viennacl.cpp", "mtl4-with-viennacl_8cpp-example.html", null ],
    [ "multithreaded.cpp", "multithreaded_8cpp-example.html", null ],
    [ "multithreaded_cg.cpp", "multithreaded_cg_8cpp-example.html", null ],
    [ "nmf.cpp", "nmf_8cpp-example.html", null ],
    [ "power-iter.cpp", "power-iter_8cpp-example.html", null ],
    [ "qr.cpp", "qr_8cpp-example.html", null ],
    [ "qr_method.cpp", "qr_method_8cpp-example.html", null ],
    [ "scheduler.cpp", "scheduler_8cpp-example.html", null ],
    [ "spai.cpp", "spai_8cpp-example.html", null ],
    [ "sparse.cpp", "sparse_8cpp-example.html", null ],
    [ "structured-matrices.cpp", "structured-matrices_8cpp-example.html", null ],
    [ "tql2.cpp", "tql2_8cpp-example.html", null ],
    [ "vector-range.cpp", "vector-range_8cpp-example.html", null ],
    [ "viennacl-info.cpp", "viennacl-info_8cpp-example.html", null ],
    [ "wrap-host-buffer.cpp", "wrap-host-buffer_8cpp-example.html", null ]
];
